if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database -q usr/share/applications >/dev/null 2>&1
fi

if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
  if [ -x /usr/bin/gtk-update-icon-cache ]; then
    /usr/bin/gtk-update-icon-cache -f usr/share/icons/hicolor >/dev/null 2>&1
  fi
fi

if [ -e usr/share/glib-2.0/schemas ]; then
  if [ -x /usr/bin/glib-compile-schemas ]; then
    /usr/bin/glib-compile-schemas usr/share/glib-2.0/schemas >/dev/null 2>&1
  fi
fi
( cd usr/share/help/ca/baobab/media ; rm -rf hicolor_apps_48x48_baobab.png )
( cd usr/share/help/ca/baobab/media ; ln -sf /usr/share/help/C/baobab/media/hicolor_apps_48x48_baobab.png hicolor_apps_48x48_baobab.png )
( cd usr/share/help/cs/baobab/media ; rm -rf hicolor_apps_48x48_baobab.png )
( cd usr/share/help/cs/baobab/media ; ln -sf /usr/share/help/C/baobab/media/hicolor_apps_48x48_baobab.png hicolor_apps_48x48_baobab.png )
( cd usr/share/help/da/baobab/media ; rm -rf hicolor_apps_48x48_baobab.png )
( cd usr/share/help/da/baobab/media ; ln -sf /usr/share/help/C/baobab/media/hicolor_apps_48x48_baobab.png hicolor_apps_48x48_baobab.png )
( cd usr/share/help/de/baobab/media ; rm -rf hicolor_apps_48x48_baobab.png )
( cd usr/share/help/de/baobab/media ; ln -sf /usr/share/help/C/baobab/media/hicolor_apps_48x48_baobab.png hicolor_apps_48x48_baobab.png )
( cd usr/share/help/el/baobab/media ; rm -rf hicolor_apps_48x48_baobab.png )
( cd usr/share/help/el/baobab/media ; ln -sf /usr/share/help/C/baobab/media/hicolor_apps_48x48_baobab.png hicolor_apps_48x48_baobab.png )
( cd usr/share/help/es/baobab/media ; rm -rf hicolor_apps_48x48_baobab.png )
( cd usr/share/help/es/baobab/media ; ln -sf /usr/share/help/C/baobab/media/hicolor_apps_48x48_baobab.png hicolor_apps_48x48_baobab.png )
( cd usr/share/help/eu/baobab/media ; rm -rf hicolor_apps_48x48_baobab.png )
( cd usr/share/help/eu/baobab/media ; ln -sf /usr/share/help/C/baobab/media/hicolor_apps_48x48_baobab.png hicolor_apps_48x48_baobab.png )
( cd usr/share/help/fi/baobab/media ; rm -rf hicolor_apps_48x48_baobab.png )
( cd usr/share/help/fi/baobab/media ; ln -sf /usr/share/help/C/baobab/media/hicolor_apps_48x48_baobab.png hicolor_apps_48x48_baobab.png )
( cd usr/share/help/fr/baobab/media ; rm -rf hicolor_apps_48x48_baobab.png )
( cd usr/share/help/fr/baobab/media ; ln -sf /usr/share/help/C/baobab/media/hicolor_apps_48x48_baobab.png hicolor_apps_48x48_baobab.png )
( cd usr/share/help/gl/baobab/media ; rm -rf hicolor_apps_48x48_baobab.png )
( cd usr/share/help/gl/baobab/media ; ln -sf /usr/share/help/C/baobab/media/hicolor_apps_48x48_baobab.png hicolor_apps_48x48_baobab.png )
( cd usr/share/help/hr/baobab/media ; rm -rf hicolor_apps_48x48_baobab.png )
( cd usr/share/help/hr/baobab/media ; ln -sf /usr/share/help/C/baobab/media/hicolor_apps_48x48_baobab.png hicolor_apps_48x48_baobab.png )
( cd usr/share/help/hu/baobab/media ; rm -rf hicolor_apps_48x48_baobab.png )
( cd usr/share/help/hu/baobab/media ; ln -sf /usr/share/help/C/baobab/media/hicolor_apps_48x48_baobab.png hicolor_apps_48x48_baobab.png )
( cd usr/share/help/id/baobab/media ; rm -rf hicolor_apps_48x48_baobab.png )
( cd usr/share/help/id/baobab/media ; ln -sf /usr/share/help/C/baobab/media/hicolor_apps_48x48_baobab.png hicolor_apps_48x48_baobab.png )
( cd usr/share/help/it/baobab/media ; rm -rf hicolor_apps_48x48_baobab.png )
( cd usr/share/help/it/baobab/media ; ln -sf /usr/share/help/C/baobab/media/hicolor_apps_48x48_baobab.png hicolor_apps_48x48_baobab.png )
( cd usr/share/help/ko/baobab/media ; rm -rf hicolor_apps_48x48_baobab.png )
( cd usr/share/help/ko/baobab/media ; ln -sf /usr/share/help/C/baobab/media/hicolor_apps_48x48_baobab.png hicolor_apps_48x48_baobab.png )
( cd usr/share/help/pl/baobab/media ; rm -rf hicolor_apps_48x48_baobab.png )
( cd usr/share/help/pl/baobab/media ; ln -sf /usr/share/help/C/baobab/media/hicolor_apps_48x48_baobab.png hicolor_apps_48x48_baobab.png )
( cd usr/share/help/pt/baobab/media ; rm -rf hicolor_apps_48x48_baobab.png )
( cd usr/share/help/pt/baobab/media ; ln -sf /usr/share/help/C/baobab/media/hicolor_apps_48x48_baobab.png hicolor_apps_48x48_baobab.png )
( cd usr/share/help/pt_BR/baobab/media ; rm -rf hicolor_apps_48x48_baobab.png )
( cd usr/share/help/pt_BR/baobab/media ; ln -sf /usr/share/help/C/baobab/media/hicolor_apps_48x48_baobab.png hicolor_apps_48x48_baobab.png )
( cd usr/share/help/ru/baobab/media ; rm -rf hicolor_apps_48x48_baobab.png )
( cd usr/share/help/ru/baobab/media ; ln -sf /usr/share/help/C/baobab/media/hicolor_apps_48x48_baobab.png hicolor_apps_48x48_baobab.png )
( cd usr/share/help/sl/baobab/media ; rm -rf hicolor_apps_48x48_baobab.png )
( cd usr/share/help/sl/baobab/media ; ln -sf /usr/share/help/C/baobab/media/hicolor_apps_48x48_baobab.png hicolor_apps_48x48_baobab.png )
( cd usr/share/help/sv/baobab/media ; rm -rf hicolor_apps_48x48_baobab.png )
( cd usr/share/help/sv/baobab/media ; ln -sf /usr/share/help/C/baobab/media/hicolor_apps_48x48_baobab.png hicolor_apps_48x48_baobab.png )
( cd usr/share/help/uk/baobab/media ; rm -rf hicolor_apps_48x48_baobab.png )
( cd usr/share/help/uk/baobab/media ; ln -sf /usr/share/help/C/baobab/media/hicolor_apps_48x48_baobab.png hicolor_apps_48x48_baobab.png )
( cd usr/share/help/zh_CN/baobab/media ; rm -rf hicolor_apps_48x48_baobab.png )
( cd usr/share/help/zh_CN/baobab/media ; ln -sf /usr/share/help/C/baobab/media/hicolor_apps_48x48_baobab.png hicolor_apps_48x48_baobab.png )
